using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Drawing;
using System.Data;
using System.Text;
using System.Windows.Forms;
using System.Configuration;

namespace UserControlSettings
{
    public partial class ColorControl : UserControl, IPersistComponentSettings
    {
        #region Fields
        private Color _backgroundColor;
        private bool _saveSettings = true;
        private string _settingsKey;
        private ColorControlSettings _settings;
        #endregion

        #region Constructors
        public ColorControl()
        {
            InitializeComponent();
            base.Disposed += new EventHandler(ColorControl_Disposed);
        }
        #endregion

        #region Properties
        /// <summary>
        /// Ruft einen Wert ab, der angibt, ob das Steuerelement die Eigenschaften seiner Anwendungseinstellungen automatisch beibehalten soll, oder legt diesen Wert fest.
        /// </summary>
        /// <value></value>
        /// <returns>true, wenn das Steuerelement automatisch seinen Zustand beibehalten soll, andernfalls false.</returns>
        public bool SaveSettings
        {
            get { return _saveSettings; }
            set { _saveSettings = value; }
        }

        /// <summary>
        /// Instanz der Einstellungsklasse des Steuerelements.
        /// </summary>
        /// <value>The settings.</value>
        [Browsable(false)]
        public ColorControlSettings Settings
        {
            get
            {
                if (_settings == null)
                    this._settings = new ColorControlSettings(this._settingsKey);
                return _settings;
            }
        }

        /// <summary>
        /// Ruft den Wert des Schlssels der Anwendungseinstellungen fr die aktuelle Instanz des Steuerelements ab oder legt diesen fest.
        /// </summary>
        /// <value></value>
        /// <returns>Ein <see cref="T:System.String"></see>, der den Schlssel der Einstellungen der aktuellen Instanz des Steuerelements enthlt.</returns>
        public string SettingsKey
        {
            get { return _settingsKey; }
            set { _settingsKey = value; }
        }
        #endregion


        #region Methods
        /// <summary>
        /// Liest die Anwendungseinstellungen des Steuerelements in die entsprechenden Eigenschaften und aktualisiert den Zustand des Steuerelements.
        /// </summary>
        public void LoadComponentSettings()
        {
            this.BackColor = this.Settings.BackgroundColor;
        }

        /// <summary>
        /// Behlt die Eigenschaften der Anwendungseinstellungen des Steuerelements bei.
        /// </summary>
        public void SaveComponentSettings()
        {
            if (_saveSettings)
            {
                this.Settings.BackgroundColor = this.BackColor;
                this.Settings.Save();
            }
        }

        /// <summary>
        /// Setzt die Eigenschaften der Anwendungseinstellungen des Steuerelements auf die Standardwerte zurck.
        /// </summary>
        public void ResetComponentSettings()
        {
            this._settings.Reload();
            this.LoadComponentSettings();
        }
        #endregion

        #region EventHandler
        private void ColorControl_Click(object sender, EventArgs e)
        {
            if (this.dlgColor.ShowDialog() == DialogResult.OK)
            {
                this.BackColor = dlgColor.Color;
            }
        }
        void ColorControl_Disposed(object sender, EventArgs e)
        {
            this.SaveComponentSettings();
        }
        #endregion
    }
}
